SAL Data Sets - Columbus

# Columbus

## Data provided "as is," no warranties

## Description

Crime data for 49 neighborhoods in Columbus, OH, 1980

Type = polygon shape file, projected, arbitrary units

Observations = 49

Variables = 20

## Source

Anselin, Luc (1988). Spatial Econometrics. Boston, Kluwer Academic, Table 12.1, p. 189.

## Variables

Variable | Description
--- | ---
AREA | neighborhood area (computed by ArcView)
PERIMETER | neighborhood perimeter (computed by ArcView)
COLUMBUS_ | internal polygon ID (generated by ArcView)
COLUMBUS_I | internal polygon ID (geneated by ArcView)
POLYID | neighborhood ID, used in GeoDa User's Guide and tutorials
NEIG | neighborhood ID, used in Spatial Econometrics examples
HOVAL | housing value (in $1,000)
INC | household income (in $1,000)
CRIME | residential burglaries and vehicle thefts per 1000 households
OPEN | open space (area)
PLUMB | percent housing units without plumbing
DISCBD | distance to CBD
X | centroid x coordinate (in arbitrary digitizing units)
Y | centroid y coordinate (in arbitrary digitizing units)
NSA | north-south indicator variable (North = 1)
NSB | other north-south indicator variable (North = 1)
EW | east-west indicator variable (East = 1)
CP | core-periphery indicator variable (Core = 1)
THOUS | constant (= 1000)
NEIGNO | another neighborhood ID variable (NEIG + 1000)

Prepared by Luc Anselin

UIUC-ACE Spatial Analysis Laboratory

Last updated June 16, 2003